var hdc1000 = require('./hdc1000_click_example')                                /**< module for HDC1000 Click */
var pressure2 = require('./pressure2_click_example')                            /**< module for Pressure2 Click */
var fs = require('fs')                                                          /**< module we used for writing files on file system */

var writeString = "Remote weather station\n";                                   /**< stores string that will be send via sms */

/**
 * @brief Gets current date and time 
 * 
 * @return Formated string with current date and time
 */
function getDateTime() {

    var date = new Date();

    var hour = date.getHours();
    hour = (hour < 10 ? "0" : "") + hour;

    var min  = date.getMinutes();
    min = (min < 10 ? "0" : "") + min;

    var sec  = date.getSeconds();
    sec = (sec < 10 ? "0" : "") + sec;

    var year = date.getFullYear();

    var month = date.getMonth() + 1;
    month = (month < 10 ? "0" : "") + month;

    var day  = date.getDate();
    day = (day < 10 ? "0" : "") + day;

    return day + "/" + month + "/" + year + "   " + hour + ":" + min + ":" + sec;

}

/**
 * @brief Measurement of current conditions
 */
function readSensors(callback){
    hdc1000.measure();
    pressure2.measure();
    
    setTimeout(callback, 500);
}

/**
 * @brief Handle synchronous execution of next function.
 */
function handleSaveValues(){
    saveValues(handleWriteFile);
}

/**
 * @brief Writes measured values to string
 */
function saveValues(callback) {
    
    var T = hdc1000.temperature();
    var H = hdc1000.humidity();
    var DP = hdc1000.dewPoint();
    var P = pressure2.pressure();
    
    writeString += getDateTime() + "\n";
    writeString += "Temperature : " + T.toFixed(1) + " C\n";
    writeString += "Humidity : " + H.toFixed(0) + " %\n";
    writeString += "Pressure : " + P.toFixed(0) + " mB\n";
    writeString += "Dew point : " + DP.toFixed(1) + " C";
        
    console.log(writeString);
        
    callback();
}

/**
 * @brief Handle synchronous execution of next function.
 */
function handleWriteFile(){
    writeFile(handleLog);
}

/**
 * @brief Writes measured values to text file
 */
function writeFile(callback){
    
    fs.writeFile("/home/RWS/LastMeasure.txt", writeString, function(err){
        if (err) {
            return console.log(err);
        }
    })
    callback();
}

/**
 * @brief Handle synchronous execution of next function.
 */
function handleLog(){
    writeLog();
}

/**
 * @brief Writes measured values to log
 */
function writeLog(){
    
    fs.appendFile("/home/RWS/Log.txt", writeString, function( err ){
        if(err) {
            return console.log(err);
        }
    })    
}

/**
 * @brief Main function
 * 
 * Executes all syncronous
 */
readSensors(handleSaveValues);